@@ -14,7 +14,8 @@
 Configure sphinx-doc through an YAML file.
 """
 
-import imp
+import datetime
+import importlib
 import os.path
 
 import sphinx_bootstrap_theme
@@ -52,7 +53,7 @@ def collect_project_and_config():
 
     project_cfg = local_config.get("project_cfg", None)
 
-    _, docs_path, _ = imp.find_module("docs_conf")
+    docs_path = importlib.util.find_spec("docs_conf").submodule_search_locations[0]
 
     default_cfg = os.path.join(docs_path, "defaults", "default.yaml")
     with open(os.path.join(docs_path, default_cfg), "r") as f:
@@ -78,7 +79,7 @@ project = cfg.get("project")
 version = cfg.get("version")
 release = cfg.get("release", version)
 author = cfg.get("author")
-copyright = cfg.get("copyright")
+copyright = cfg.get("copyright").format(datetime.datetime.now().year)
 
 needs_sphinx = cfg.get("needs_sphinx", "1.0")
 exclude_patterns = cfg.get("exclude_patterns", [])
